import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Icon, Select, message, Table, Typography, Pagination, Modal } from 'antd';
import router from 'umi/router';
import moment from 'moment';
import AuthButton from '@/components/AuthButton';
import withActions from '@/components/ActionList';
import EditIcon from '@/components/EditIcon';
import Navigate from '@/components/Navigate';
import Prompt from 'umi/prompt';
import SelectCity from '../../../components/SelectButton/CitySelect'
import BuildSelect from '../../../components/SelectButton/BuildSelect'
import apis from '../../../services/apis';
import request from '../../../utils/request';
import styles from '../../style/GoodsList.less';

const { Option } = Select;

const header = props => {
  const [data, setData] = useState({})
  //   const [page, changePage] = useState({})

  useEffect(() => {
    if (localStorage.getItem("groupActivePageParams")) {
      props.form.setFieldsValue(JSON.parse(localStorage.getItem("groupActivePageParams")));
      // const { getFieldDecorator } = JSON.parse(localStorage.getItem("pageParams"))

      getList(JSON.parse(localStorage.getItem("groupActivePageParams")))
    } else {
      localStorage.setItem("groupActivePageParams", JSON.stringify({ pageNum: 1, pageSize: 10 }));
      getList({ pageNum: 1, pageSize: 10 });
    }

  }, [])

  // 查询列表
  const getList = (params) => {
    console.log(params);
    request({ ...apis.groupActivity.list, params: { ...params } }).then((data) => {
      console.log(data)
      setData(data)
    })
  }


  // 跳转到拼团活动新增
  const toEditActivity = (groupActivityId) => () => {
    router.push({
      pathname: '/activity/groupActivity/editGroupActivity',
      query: {
        groupActivityId
      },
    });
  }

  const getActivityDetail = (groupActivityId) => () => {
    router.push({
      pathname: '/activity/groupActivity/detailActivity',
      query: {
        groupActivityId,
      },
    });
  }

  const getJoinPeople = (groupActivityId) => () => {
    router.push({
      pathname: '/activity/groupActivity/helpRecord',
      query: {
        groupActivityId,
      },
    });
  }

  const toDataReacord = id => {
    router.push({
      pathname: '/activity/groupActivity/groupActivityRecord',
      query: {
        id,
      },
    });
  }

  /**
   *
   *
   * @param {*} props
   * @returns
   */

  const columns = [
    {
      title: '活动标题',
      dataIndex: 'activityName',
      key: 'activityName',
      align: 'center',
      render: (x, row) => <Navigate onClick={getActivityDetail(row.groupActivityId)}><Typography.Text ellipsis>{row.activityName}</Typography.Text></Navigate>,
    },
    {
      title: '活动时间',
      dataIndex: 'startTime',
      key: 'startTime',
      align: 'center',
      render: (x, row) => <><span>{`${moment(row.startTime).format('YYYY-MM-DD HH:mm:ss')} —— ${moment(row.endTime).format('YYYY-MM-DD HH:mm:ss')}`}</span></>
    },
    {
      title: '所需积分',
      dataIndex: 'integral',
      key: 'integral',
      align: 'center',
    },
    {
      title: '已参与人数',
      dataIndex: 'participateNum',
      key: 'participateNum',
      align: 'center',
      render: (x, row) => <><div style={{ overflow: 'hidden', textOverflow: 'ellipsis', whiteSpace: 'nowrap', width: '201px', title: 'content' }}>
        <Navigate onClick={getJoinPeople(row.groupActivityId)}>{row.participateNum}</Navigate>
        </div></>,
    },
    {
      title: '成团数',
      dataIndex: 'groupBuyPeople',
      key: 'groupBuyPeople',
      align: 'center',
    },
    {
      title: '状态',
      dataIndex: 'activityStatus',
      key: 'activityStatus',
      align: 'center',
      render: (text, records) => {
        if (records.activityStatus === 0) { return '进行中' }
        if (records.activityStatus === 1) { return '未开始' }
        if (records.activityStatus === 2) { return '已结束' }
      },
    },
    {
      title: '权重',
      dataIndex: 'heavy',
      key: 'heavy',
      align: 'center',
    },
    {
      title: '操作',
      dataIndex: 'handle',
      key: 'handle',
      align: 'center',
      width: 400,
      render: withActions((x, row) => [

        <EditIcon type="look" text="查看详情" onClick={getActivityDetail(row.groupActivityId)} />,

        row.activityStatus === 0 ?
          <AuthButton name="admin.taShareActivity.finish.put" noRight={null}>
            <EditIcon type="end" text="结束活动" onClick={endGroupActivity(row)} />
          </AuthButton> : null,

          <AuthButton name="admin.taShareActivity.publish" noRight={null}>
            <EditIcon type={row.status === 1 ? 'cancel' : 'publish'} text={row.status === 1 ? '取消发布' : '发布'} onClick={sendOrPublicDynamic.bind(this, row)} />
          </AuthButton>,

          <AuthButton name="admin.taShareActivity.tag" noRight={null}>
            <EditIcon type={row.weight === 1 ? 'cancel' : 'add'} text={row.weight === 1 ? '取消标签' : '添加标签'} onClick={topGroupActivity(row, row.weight)} />
          </AuthButton>,
            
          <AuthButton name="admin.taShareActivity.top" noRight={null}>
            <EditIcon type={row.sort ? 'cancel' : 'top'} text={row.sort ? '取消推首页' : '推荐首页'} onClick={recommendGroupActivity(row)} />
          </AuthButton>,

          <AuthButton name="admin.groupActivity.dataRecord" noRight={null}>
            <EditIcon type="record" text="数据记录" onClick={() => toDataReacord(row.groupActivityId)} />
          </AuthButton>,

          (row.activityStatus === 0 || row.activityStatus === 1) ?
            <AuthButton name="admin.taShareActivity.update.put" noRight={null}>
              <EditIcon type="edit" text="编辑" onClick={toEditActivity(row.groupActivityId)} />
            </AuthButton> : null,
      ]),
    },
  ];

  const finishDynamic = (row) => {
    Modal.confirm({
      title: '结束以后将无法编辑, 是否继续?',
      okText: '确定',
      cancelText: '取消',
      onOk() {
        request({ ...apis.activity.finish, data: { dynamicId: row.dynamicId, top: "" } }).then((data) => {
          console.log(data)
          message.info('操作成功！')
          getList(JSON.parse(localStorage.getItem("groupActivePageParams")))
        }).catch((err) => {
          console.log(err)
          message.info(err.msg || err.message)
        })
      },
    });
  }

  //结束活动
  const endGroupActivity = (row) => () => {
    Modal.confirm({
      title: '活动会被强制结束，小程序端无法再发起或参与此拼团，如果不想让客户看到活动，请再点击取消发布按钮',
      okText: '确定',
      cancelText: '取消',
      onOk() {
        request({ ...apis.groupActivity.finish, urlData: { id: row.groupActivityId } }).then((data) => {
          console.log(data)
          message.info('操作成功！')
          getList(JSON.parse(localStorage.getItem("groupActivePageParams")))
        }).catch((err) => {
          console.log(err)
          message.info(err.msg || err.message)
        })
      },
    });
  }

  //置顶
  const topGroupActivity = (row, weight) => () => {
    request({ ...apis.groupActivity.top, data: { groupActivityId: row.groupActivityId, weight: weight } }).then((data) => {
      console.log(data)
      message.info('操作成功！')
      getList(JSON.parse(localStorage.getItem("groupActivePageParams")))
    }).catch((err) => {
      console.log(err)
      message.info(err.msg || err.message)
    })
  }

  const sendOrPublicDynamic = row => {
    if (row.status === 1) {
      cancelDynamic(row)
    } else {
      sendDynamic(row)
    }
  }

  // 取消活动
  const cancelDynamic = row => {
    Modal.confirm({
      title: '活动会在小程序端隐藏，后台可以继续编辑重新发布',
      okText: '确认',
      cancelText: '取消',
      onOk() {
        request({ ...apis.groupActivity.cancel, urlData: { id: row.groupActivityId } }).then(data => {
          message.info('操作成功！')
          getList(JSON.parse(localStorage.getItem("groupActivePageParams")))
        }).catch(err => {
          console.log(err)
          message.info(err.msg || err.message)
        })
      }
    });
  }

  // 发布活动
  const sendDynamic = row => {
    Modal.confirm({
      title: '确定发布吗？',
      okText: '确认',
      cancelText: '取消',
      onOk() {
        request({ ...apis.groupActivity.send, urlData: { id: row.groupActivityId } }).then(data => {
          message.info('操作成功！')
          getList(JSON.parse(localStorage.getItem("groupActivePageParams")))
        }).catch(err => {
          console.log(err)
          message.info(err.msg || err.message)
        })
      }
    });
  }

  //首页推荐
  const recommendGroupActivity = (row, code) => () => {
    request({ ...apis.groupActivity.top, data: { groupActivityId: row.groupActivityId, sort: row.sort } }).then((data) => {
      console.log(data)
      message.info('操作成功！')
      getList(JSON.parse(localStorage.getItem("groupActivePageParams")))
    }).catch((err) => {
      console.log(err)
      message.info(err.msg || err.message)
    })
  }

  const changePageNum = pageNumber => {
    localStorage.setItem("groupActivePageParams", JSON.stringify({ pageNum: pageNumber, pageSize: 10, ...props.form.getFieldsValue() }));

    getList({ pageNum: pageNumber, pageSize: 10, ...props.form.getFieldsValue() })
  }

  // 提交事件
  const handleSubmit = (e, props) => {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        console.log('提交数据: ', values)
        localStorage.setItem("groupActivePageParams", JSON.stringify({ pageNum: 1, pageSize: 10, ...values }));
        getList({ pageNum: 1, pageSize: 10, ...values })
      }
    });
  }

  //重置搜索
  function handleReset() {
    props.form.resetFields();
    localStorage.setItem("groupActivePageParams", JSON.stringify({ pageNum: 1, pageSize: 10 }));
    getList({ pageNum: 1, pageSize: 10 })
  }


  const { getFieldDecorator } = props.form
  return (

    <>
      <Form layout="inline" onSubmit={e => handleSubmit(e, props)}>
        <Form.Item>
          {getFieldDecorator('cityId')(
            <SelectCity />,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('buildingId')(
            <BuildSelect />,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('activityName')(
            <Input
              prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
              placeholder="请输入标题"
            />,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('activityStatus')(
            <Select style={{ width: '180px' }} placeholder="活动状态">
              <Option value="0">进行中</Option>
              <Option value="1">未开始</Option>
              <Option value="2">已结束</Option>
            </Select>,
          )}
        </Form.Item>
        <Form.Item>
          <AuthButton name="admin.taShareActivity.search" noRight={null}>
            <Button type="primary" htmlType="submit" className={styles.searchBtn}>
              搜索
          </Button>
          </AuthButton>
          <Button style={{ marginLeft: 8 }} onClick={handleReset}>
            重置
            </Button>
        </Form.Item>
      </Form>
      <AuthButton name="admin.taShareActivity.post" noRight={null}>
        <Button type="danger" className={styles.addBtn} onClick={toEditActivity()}>新增</Button>
      </AuthButton>
      <Table
        // onRow={record => {
        //     return {
        //       onClick: getActivityDetail(record.groupActivityId),
        //     };
        //   }}
        style={{ marginTop: '30px' }} dataSource={data.records} columns={columns} pagination={false} rowKey="activityList" />
      <div style={{ display: 'flex', justifyContent: 'flex-end', marginTop: '30px' }}>
        <Pagination showQuickJumper defaultCurrent={1} total={data.total} onChange={changePageNum} current={data.current} />
      </div>
      <Prompt message={location =>
        location.pathname.startsWith("/activity/groupActivity")
          ? true
          : localStorage.removeItem("groupActivePageParams")} />
    </>
  )
}
const WrappedHeader = Form.create({ name: 'header' })(header);

export default WrappedHeader
